.. _axes_grid-api-index:

#######################################
  The Matplotlib AxesGrid Toolkit API
#######################################

:Release: |version|
:Date: |today|

.. toctree::

    axes_size_api.rst
    axes_divider_api.rst
    axes_grid_api.rst
    axis_artist_api.rst


#######################################
  The Matplotlib axes_grid1 Toolkit API
#######################################

:Release: |version|
:Date: |today|

.. toctree::

    anchored_artists_api.rst
    inset_locator_api.rst
